@@ -17,7 +17,7 @@
 import json
 import os
 from abc import ABC
-from typing import List
+from typing import List, Union
 
 from hspylib.core.enums.http_code import HttpCode
 from hspylib.core.tools.commons import sysout
@@ -38,16 +38,21 @@ class FileProcessor(ABC):
         file_data = []
         for f_path in file_paths:
             check_state(os.path.exists(f_path), f'Input file "{f_path}" does not exist')
-            file = FileProcessor._read_and_encode(f_path)
-            file_data.append(file)
+            if os.path.isfile(f_path):
+                f_entry = FileProcessor._read_and_encode(f_path)
+                file_data.append(f_entry)
+            else:
+                for file in next(os.walk(f_path))[2]:
+                    f_entry = FileProcessor._read_and_encode(os.path.join(f_path, file))
+                    file_data.append(f_entry)
         payload = FileProcessor._to_json(file_data)
         response = put(url, payload)
         check_not_none(response)
         if response.status_code != HttpCode.OK:
             raise HTTPError(
-                '{response.status_code} - Unable to upload into={url} with json_string={payload}')
-        paths = ', \n\t'.join(file_paths)
-        sysout(f"%GREEN%File(s) [\n\t{paths}\n] successfully uploaded to {url}%NC%")
+                f'{response.status_code} - Unable to upload into={url} with json_string={payload}')
+        paths = ', \n\t'.join([f.path for f in file_data])
+        sysout(f"%GREEN%File(s) [\n\t{paths}\n] successfully uploaded to: {url}%NC%")
 
         return len(file_data)
 
@@ -65,9 +70,13 @@ class FileProcessor(ABC):
             raise HTTPError(
                 f'{response.status_code} - Unable to download from={url} with response={response}')
         file_data = FileProcessor._from_json(response.body)
-        FileProcessor._decode_and_write(destination_dir, file_data)
+        if file_data and len(file_data) > 0:
+            FileProcessor._decode_and_write(destination_dir, file_data)
+            return len(file_data)
 
-        return len(file_data)
+        sysout(f'%ORANGE%Database alias was not found in: {url} %NC%')
+
+        return 0
 
     @staticmethod
     def _read_and_encode(file_path: str) -> FileEntry:
@@ -75,20 +84,23 @@ class FileProcessor(ABC):
         return FileEntry(file_path).encode()
 
     @staticmethod
-    def _decode_and_write(destination_dir: str, file_entries: List[dict]) -> None:
+    def _decode_and_write(destination_dir: str, data: Union[dict, List[dict]]) -> None:
         """B64 decode and write entries to file"""
-        for entry in file_entries:
-            FileEntry.of(
-                f"{destination_dir}/{os.path.basename(entry['path'])}",
-                entry['data'],
-                entry['size']).save()
-        files = ', \n\t'.join(list(map(lambda e: os.path.basename(e['path']), file_entries)))
-        sysout(f'%GREEN%File(s) [\n\t{files}\n] successfully downloaded into {destination_dir}%NC%')
+        if isinstance(data, list):
+            for entry in data:
+                FileEntry \
+                    .of(f"{destination_dir}/{os.path.basename(entry['path'])}", entry['data'], entry['size']).save()
+            paths = ', \n\t'.join([f['path'] for f in data])
+        else:
+            FileEntry \
+                .of(f"{destination_dir}/{os.path.basename(data['path'])}", data['data'], data['size']).save()
+            paths = data['path']
+        sysout(f"%GREEN%File(s) [\n\t{paths}\n] successfully downloaded into: {destination_dir}%NC%")
 
     @staticmethod
     def _to_json(file_data: List[FileEntry]) -> str:
         """Convert the file data into json format"""
-        return '[' + ', '.join([str(entry) for entry in file_data]) + ']'
+        return '[' + ','.join([str(entry) for entry in file_data]) + ']'
 
     @staticmethod
     def _from_json(file_data: str) -> List[dict]:
