@@ -18,17 +18,19 @@ import json
 from datetime import datetime
 from typing import List
 
-from firebase.entity.file_entry import FileEntry
 from hspylib.core.enums.charset import Charset
 
+from firebase.entity.file_entry import FileEntry
+
 
 class FirebaseEntry:
 
-    def __init__(self,
-                 name: str = None,
-                 last_update_user: str = None,
-                 files: List[FileEntry] = None,
-                 encoding: Charset = Charset.UTF_8):
+    def __init__(
+        self,
+        name: str = None,
+        last_update_user: str = None,
+        files: List[FileEntry] = None,
+        encoding: Charset = Charset.UTF_8):
         self.name = name
         self.last_update_user = last_update_user
         self.files = files if files else []
